==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETControlFlowNode.h <==
// public abstract class soot.dava.internal.SET.SETControlFlowNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETControlFlowNode_H_
#define _JC_soot_dava_internal_SET_SETControlFlowNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	_jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$refs	_jc_soot_dava_internal_SET_SETControlFlowNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs	_jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$object	_jc_soot_dava_internal_SET_SETControlFlowNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtable	_jc_soot_dava_internal_SET_SETControlFlowNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtype	_jc_soot_dava_internal_SET_SETControlFlowNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETControlFlowNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETControlFlowNode$method$get__5fCharacterizingStmt$a907b06061842d3d(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *);
extern jboolean _jc_soot_dava_internal_SET_SETControlFlowNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETControlFlowNode$method_info$get__5fCharacterizingStmt$a907b06061842d3d;
extern _jc_method _jc_soot_dava_internal_SET_SETControlFlowNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vmethods {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fCharacterizingStmt$a907b06061842d3d)(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *);
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*characterizingStmt;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$refs {
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETControlFlowNode$object {
	_jc_soot_dava_internal_SET_SETControlFlowNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETControlFlowNode$vtype _jc_soot_dava_internal_SET_SETControlFlowNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETControlFlowNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETControlFlowNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETControlFlowNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETControlFlowNode.h <==
// public abstract class soot.dava.internal.SET.SETControlFlowNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETControlFlowNode_H_
#define _JC_soot_dava_internal_SET_SETControlFlowNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	_jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$refs	_jc_soot_dava_internal_SET_SETControlFlowNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs	_jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETControlFlowNode$object	_jc_soot_dava_internal_SET_SETControlFlowNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtable	_jc_soot_dava_internal_SET_SETControlFlowNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtype	_jc_soot_dava_internal_SET_SETControlFlowNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETControlFlowNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETControlFlowNode$method$get__5fCharacterizingStmt$a907b06061842d3d(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_SET_SETControlFlowNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETControlFlowNode$method_info$get__5fCharacterizingStmt$a907b06061842d3d;
extern _jc_method _jc_soot_dava_internal_SET_SETControlFlowNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vmethods {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fCharacterizingStmt$a907b06061842d3d)(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *) _JC_JCNI_ATTR;
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETControlFlowNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs {
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*characterizingStmt;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$refs {
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETControlFlowNode$object {
	_jc_soot_dava_internal_SET_SETControlFlowNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETControlFlowNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETControlFlowNode$vtype _jc_soot_dava_internal_SET_SETControlFlowNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETControlFlowNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETControlFlowNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETControlFlowNode_H_ */
